#
# spec file for package lmdb
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           lmdb
Summary:        Lightning Memory-Mapped Database Manager
License:        OLDAP-2.8
Group:          Productivity/Databases/Tools
%define lname	liblmdb-0_9_14
Version:        0.9.14
Release:        5.4
Url:            http://symas.com/mdb/

#Git-Clone:	git://git.openldap.org/openldap mdb.master
Source:         %{name}-%{version}.tar.bz2
Source99:       baselibs.conf
Patch1:         automake.diff
Patch2:         0001-Patch-for-LMDB-to-use-robust-mutexes.patch
Patch3:         0002-Add-extra-tools-and-CFEngine-modifications-for-LMDB.patch
Patch4:         liblmdb-implicit-decl.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake >= 1.10
BuildRequires:  libtool >= 2

%description
LMDB is a Btree-based database management library with an API similar
to BerkeleyDB. The library is thread-aware and supports concurrent
read/write access from multiple processes and threads. The DB
structure is multi-versioned, and data pages use a copy-on-write
strategy, which also provides resistance to corruption and eliminates
the need for any recovery procedures. The database is exposed in a
memory map, requiring no page cache layer of its own.

%package -n %lname
Summary:        Shared library for Lightning Memory-Mapped Database (LMDB)
Group:          System/Libraries

%description -n %lname
LMDB is a Btree-based database management library with an API similar
to BerkeleyDB. The library is thread-aware and supports concurrent
read/write access from multiple processes and threads. The DB
structure is multi-versioned, and data pages use a copy-on-write
strategy, which also provides resistance to corruption and eliminates
the need for any recovery procedures. The database is exposed in a
memory map, requiring no page cache layer of its own.

This package contains the shared library.

%package devel
Summary:        Development package for lmdb
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
LMDB is a Btree-based database management library with an API similar
to BerkeleyDB. The library is thread-aware and supports concurrent
read/write access from multiple processes and threads. The DB
structure is multi-versioned, and data pages use a copy-on-write
strategy, which also provides resistance to corruption and eliminates
the need for any recovery procedures. The database is exposed in a
memory map, requiring no page cache layer of its own.
 
This package contains the files needed to compile programs that use
the liblmdb library.

%prep
%setup -qn liblmdb
# PATCH-FIX-OPENSUSE - autotools files, jengelh@inai.de
%patch1 -p1
# PATCH-FIX-UPSTREAM - prevent deadlock when process holding db lock dies, kkaempf@suse.de
%patch2 -p1
# PATCH-FIX-OPENSUSE - debugging tools (https://github.com/kacfengine/lmdb)
%patch3 -p1
# PATCH-FIX-OPENSUSE - Implicit declaration of atol()
%patch4 -p1

%build
mkdir -p m4
autoreconf -fi
%configure --disable-static
make %{?_smp_mflags} V=1

%install
make install DESTDIR="%buildroot"
rm -f "%buildroot/%_libdir"/*.la

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc CHANGES
%doc COPYRIGHT
%doc LICENSE
%{_bindir}/*
%doc %{_mandir}/man1/*

%files -n %lname
%defattr(-,root,root)
%_libdir/liblmdb-%version.so

%files devel
%defattr(-,root,root)
%_includedir/*
%_libdir/liblmdb.so

%changelog
* Fri Sep 18 2015 dimstar@opensuse.org
- Add baselibs.conf: liblmdb*-32bit is required by
  libKF5Baloo5-32bit.
* Tue Mar 31 2015 hrvoje.senjan@gmail.com
- Update to 0.9.14:
  * Fix to support 64K page size (ITS#7713)
  * Fix to persist decreased as well as increased mapsizes (ITS#7789)
  * Fix cursor bug when deleting last node of a DUPSORT key
  * Fix mdb_env_info to return FIXEDMAP address
  * Fix ambiguous error code from writing to closed DBI (ITS#7825)
  * Fix mdb_copy copying past end of file (ITS#7886)
  * Fix cursor bugs from page_merge/rebalance
  * Fix to dirty fewer pages in deletes (mdb_page_loose())
  * Fix mdb_dbi_open creating subDBs (ITS#7917)
  * Fix mdb_cursor_get(_DUP) with single value (ITS#7913)
  * Fix Windows compat issues in mtests (ITS#7879)
  * Add compacting variant of mdb_copy
  * Add BigEndian integer key compare code
  * Add mdb_dump/mdb_load utilities
  - Changes since 0.9.13:
  * Fix mdb_page_alloc unlimited overflow page search
  * Documentation:
  Re-fix MDB_CURRENT doc (ITS#7793)
  Fix MDB_GET_MULTIPLE/MDB_NEXT_MULTIPLE doc
  - Changes since 0.9.12:
  * Fix MDB_GET_BOTH regression (ITS#7875,#7681)
  * Fix MDB_MULTIPLE writing multiple keys (ITS#7834)
  * Fix mdb_rebalance (ITS#7829)
  * Fix mdb_page_split (ITS#7815)
  * Fix md_entries count (ITS#7861,#7828,#7793)
  * Fix MDB_CURRENT (ITS#7793)
  * Fix possible crash on Windows DLL detach
  * Misc code cleanup
  * Documentation:
  mdb_cursor_put: cursor moves on error (ITS#7771)
- Rebase automake.diff and 0001-Patch-for-LMDB-to-use-robust-mutexes.patch
* Wed Sep 10 2014 crrodriguez@opensuse.org
- automake.diff changes:
  * for autoconf tests to have effect, (like those in
  0001-Patch-for-LMDB-to-use-robust-mutexes.patch) config.h must be
  included as first file in all C code.
  * in 32 bit systems, ensure we support large databases.
  * Switch the compiler to the current C standard, currently -std=gnu99
  in upcoming autoconf versions it is C11 though.
- liblmdb-implicit-decl.patch atol() requires stdlib.h
- Enable verbose build, rpmlint depends on that to work.
* Mon Jul 28 2014 kkaempf@suse.com
- Prevent deadlock when process holding the db lock dies
  0001-Patch-for-LMDB-to-use-robust-mutexes.patch
- command line tools for debugging
  0002-Add-extra-tools-and-CFEngine-modifications-for-LMDB.patch
* Fri May 16 2014 jengelh@inai.de
- Replace verbose cmake script (remove CMakeLists.txt).
- Instead, use a simpler automake patch (add automake.diff).
- There is a change in shared library versioning scheme to line up
  with our packaging guidelines. This is embodied within
  automake.diff.
- Shorten the description by 2/3, focus on the important points.
- Do not unnecessarily pull in a C++ compiler for the build.
- Invoke ldconfig directly as %%post rather than sh+ldconfig.
* Wed Feb 12 2014 kkaempf@suse.com
- Switch to cmake, fix dynamic lib build and versioning.
  Drop liblmdb.patch
  Add VERSION.cmake and CMakeLists.txt
* Thu Feb  6 2014 ro@suse.de
- at least set an soname, a version would be even better
* Mon Feb  3 2014 kkaempf@suse.com
- Initial version 0.9.11
